===============================
ultra-config
===============================


.. image:: https://img.shields.io/pypi/v/ultra_config.svg
        :target: https://pypi.python.org/pypi/ultra_config

.. image:: https://img.shields.io/travis/timmmartin19/ultra_config.svg
        :target: https://travis-ci.org/timmmartin19/ultra_config

.. image:: https://readthedocs.org/projects/ultra-config/badge/?version=latest
        :target: https://ultra-config.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/timmmartin19/ultra_config/shield.svg
     :target: https://pyup.io/repos/github/timmmartin19/ultra_config/
     :alt: Updates


An extendable configuration that enables you to configure your application via python modules, config files, environment variables and more!


* Free software: MIT license
* Documentation: https://ultra-config.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

